'Writing PICAXE BASIC Code
'PICAXE Tutorial
'Experiment: PICAXE 08M2 with Wi-Fi
'10 Nov 2015
'Schematic: PA-08M2 ESP-01.dch
'Code: PICAXE 08M2 ESP-01.bas
'Overview: Read temperature from DS18B20 into an 08M2,connect an 08M2 to an ESP-01 for
	'Wi-Fi operation, and send temperature to Thingspeak every 15 minutes.
#picaxe 08M2 'Identify the PICAXE being used as an 08M2.
#no_data 'Prevent data from being downloaded to PICAXE.
symbol temp=C.1 'DS18B20 should be connected to Pin C.1.
symbol baud=T4800_4 'Set baud rate for serout transmissions.
symbol temp_now = b1 'Symbol and storage location for most recent temperature reading
	'from DS18B20.
main:
readtemp C.1, temp_now 'Read temperature from DS18B20, and store it in b1.
bintoascii temp_now,b11,b12,b13 'Convert current temperature from binary to ASCII.

serout C.4,baud,("AT",13,10) 'Send attention command+CR+LF to ESP-01.
	pause 2000 'Pause 2 seconds to allow ESP-01 time to respond.
serout C.4,baud,("AT+CWQAP",13,10) 'Send disconnect from Wi-Fi command+CR+LF to ESP-01.
	pause 5000 'Pause 5 seconds to allow ESP-01 time to respond.
serout C.4,baud,("AT+RST",13,10) 'Send reset command+CR+LF to ESP-01.
	pause 3000 'Pause 3 seconds to allow ESP-01 time to respond.
serout C.4,baud,("AT+CWMODE_CUR=1",13,10) 'Send STA command+CR+LF to ESP-01.
	pause 1000 'Pause 1 second to allow ESP-01 time to respond.
serout C.4,baud,("AT+CWJAP_CUR=",34,"MyLocalLAN",34,",",34,"YSQQBU2DU6S",34,13,10)
	'Send command string to join LAN+SSID+LAN password+CR+LF to ESP-01. The "34" codes
	'send commas to separate the data for the ESP-01.
	pause 12000 'Pause 12 seconds to allow ESP-01 and LAN time to respond.
serout C.4,baud,("AT+CIPSTART=",34,"TCP",34,",",34,"184.106.153.149",34,",80",13,10)
	'Send command string to ESP-01+CR+LF to access Thingspeak.
	pause 2000 'Pause 2 seconds to allow ESP-01 and Thingspeak time to respond.
serout C.4,baud,("AT+CIPSEND=45",13,10)
	'Send AT+CIPSEND command+byte total+CR+LF to ESP-01 to advise Thingspeak to expect
	'45 bytes of data. Note that the number of bytes advised must agree with the number 
	'of bytes sent in the next serout command. The quotation marks and the commas don't  
	'count, but everything else does. Count the bytes in the following serout command to
	'see that they do total 45. Each time you change the length of the data sent, you
	'must change the total in the AT+CIPSEND command string to agree.
	pause 1000 'Pause 1 second to allow ESP-01 and Thingspeak time to respond.
serout C.4,baud,("GET /update?key=GARK3BZZWORL7SLI&field1=",b11,b12,b13,13,10)
	'Send write key+temperature+CR+LF to Thingspeak. Note that this transmission
	'includes data for only Field 1. Add an additional field and data by adding &field2
	'plus the data for as many fields as are available. Change the AT+CIPSEND command
	'string to agree with the new byte total.
	pause 5000
	'Pause 5 seconds to allow Thingspeak time to respond.

for w7 = 1 to 868 'Establish a for/next loop for 868 repetitions.
	pause 1000 'Pause 1 second.
next w7 'Next loop: 868 seconds + 32 seconds for program execution = 15 minutes.

goto main